@@ -54,7 +54,7 @@ def test_individual_boundaries():
     """ test setting individual boundaries """
     g = UnitGrid([2])
     for data in ['value', {'value': 1}, {'type': 'value', 'value': 1},
-                 'derivative', {'derivative': 1},
+                 'natural', 'derivative', {'derivative': 1},
                  {'type': 'derivative', 'value': 1}, {'mixed': 1},
                  {'type': 'mixed', 'value': 1}, 'extrapolate']:
         bc = BCBase.from_data(g, 0, upper=True, data=data, rank=0)
@@ -202,6 +202,13 @@ def test_mixed_condition():
     assert bc.get_virtual_point(data) == pytest.approx(-1)
     bc = BCBase.from_data(g, 0, True, {'type': 'mixed', 'value': np.inf})
     assert bc.get_virtual_point(data) == pytest.approx(-2)
+    
+    g = UnitGrid([2, 2])
+    data = np.ones(g.shape)
+    bc = BCBase.from_data(g, 0, False, {'type': 'mixed', 'value': [1, 2],
+                                        'const': [3, 4]})
+    assert bc.get_virtual_point(data, (0, 0)) == pytest.approx(2 + 1/3)
+    assert bc.get_virtual_point(data, (0, 1)) == pytest.approx(2)
         
         
         
