@@ -6,21 +6,31 @@ Base classes for storing data
 
 import logging
 from abc import ABCMeta, abstractmethod
-from typing import Optional, List, Tuple, Iterator, Union, Sequence, Any
+from typing import (Optional, List, Tuple, Iterator, Union, Sequence, Any,
+                    TYPE_CHECKING)
 
 import numpy as np
 
 from ..grids.base import GridBase
-from ..fields import ScalarField, VectorField, Tensor2Field
+from ..fields import ScalarField, VectorField, Tensor2Field, FieldCollection
 from ..fields.base import FieldBase
 from ..trackers.base import TrackerBase, InfoDict
 from ..trackers.intervals import IntervalType, IntervalData
 from ..tools.docstrings import fill_in_docstring
 
+if TYPE_CHECKING:
+    from .memory import MemoryStorage  # @UnusedImport
+
 
     
 class StorageBase(metaclass=ABCMeta):
-    """ base class for storage of discretized fields """
+    """ base class for storing time series of discretized fields
+    
+    These classes store time series of subclasses of
+    :class:`~pde.fields.base.FieldBase`, i.e., they store the values of the
+    fields at particular time points. Iterating of the storage will return the
+    fields in order and indivdual time points can also be accessed.
+    """
     
     
     times: Sequence[float]  # :class:`numpy.ndarray`): stored time points
@@ -82,7 +92,7 @@ class StorageBase(metaclass=ABCMeta):
     def __len__(self):
         """ return the number of stored items, i.e., time steps """
         return len(self.times)
-        
+
 
     @property
     def shape(self) -> Optional[Tuple[int, ...]]:
@@ -93,6 +103,17 @@ class StorageBase(metaclass=ABCMeta):
             return None
     
     
+    @property
+    def has_collection(self) -> bool:
+        """ bool: whether the storage is storing a collection """
+        if self._field is not None:
+            return isinstance(self._field, FieldCollection)
+        elif len(self) > 0:
+            return isinstance(self._get_field(0), FieldCollection)            
+        else:
+            raise RuntimeError('Storage is empty')
+
+    
     @property
     def grid(self) -> Optional[GridBase]:
         """ GridBase: the grid associated with this storage
@@ -109,20 +130,23 @@ class StorageBase(metaclass=ABCMeta):
         return self._grid
     
     
-    def get_field(self, index: int) -> FieldBase:
-        """ return the field corresponding to index
+    def _get_field(self, t_index: int) -> FieldBase:
+        """ return the field corresponding to the given time index
         
         Load the data associated with a given index, i.e., with time 
-        `self.times[index]`.
+        `self.times[t_index]`.
         
         Args:
-            index (int):
+            t_index (int):
                 The index of the data to load
                 
         Returns:
             :class:`~pde.fields.FieldBase`:
             The field class containing the grid and data
         """
+        if not 0 <= t_index < len(self):
+            raise IndexError("Time index out of range") 
+        
         if self._field is None:
             # we need to determine the field type
             
@@ -145,7 +169,7 @@ class StorageBase(metaclass=ABCMeta):
                 # dimensions). What is left should be the (local) data stored
                 # at each grid point for each time step. Note that self.data
                 # might be a list of arrays
-                local_shape = self.data[index].shape[:-self.grid.num_axes]
+                local_shape = self.data[t_index].shape[:-self.grid.num_axes]
                 dim = self.grid.dim
                 if len(local_shape) == 0:  # rank 0
                     self._field = ScalarField(self.grid)
@@ -162,16 +186,16 @@ class StorageBase(metaclass=ABCMeta):
                                      f'{self._field.__class__.__name__}.')
                     
         # create the field with the data of the given index
-        return self._field.copy(data=self.data[index])
+        return self._field.copy(data=self.data[t_index])
         
         
     def __getitem__(self, key: Union[int, slice]) \
             -> Union[FieldBase, List[FieldBase]]:
         """ return field at given index or a list of fields for a slice """
         if isinstance(key, int):
-            return self.get_field(key)
+            return self._get_field(key)
         elif isinstance(key, slice):
-            return [self.get_field(i)
+            return [self._get_field(i)
                     for i in range(*key.indices(len(self)))]
         else:
             raise TypeError('Unknown key type')
@@ -232,8 +256,85 @@ class StorageBase(metaclass=ABCMeta):
         """ finalize the storage after writing """
         pass
 
+         
+    def extract_field(self, field_index: int) -> "MemoryStorage":
+        """ extract the time course of a single field in a collection
+         
+        Note:
+            This might return a view into the original data, so modifying the
+            returned data can also change the underlying original data.
+         
+        Args:
+            field_index (index):
+                The index into the field collection
+                 
+        Returns:
+            :class:`MemoryStorage`: a storage instance that contains the data
+            for the single field
+        """
+        from .memory import MemoryStorage  # @Reimport
+        
+        # get the field to check its type
+        if not isinstance(self._field, FieldCollection):
+            raise TypeError('Can only extract fields from FieldCollections')
+        
+        # extract the field and the associated time series
+        field_obj = self._field[field_index]
+        field_slice = self._field._slices[field_index]
+        data = [d[field_slice].reshape(field_obj.data.shape)
+                for d in self.data]
+        
+        # create the corresponding MemoryStorage
+        return MemoryStorage(times=self.times,
+                             data=data,
+                             field_obj=field_obj,
+                             info=self.info)
 
-    
+
+          
+    def extract_time_range(self,
+                           t_range: Union[float, Tuple[float, float]] = None) \
+            -> "MemoryStorage":
+        """ extract a particular time interval
+        
+        Note:
+            This might return a view into the original data, so modifying the
+            returned data can also change the underlying original data.
+        
+        Args:
+            t_range (float or tuple):
+                Determines the range of time points included in the result. If
+                only a single number is given, all data up to this time point
+                are included.
+                
+        Returns:
+            :class:`MemoryStorage`: a storage instance that contains the
+            extracted data.
+        """
+        from .memory import MemoryStorage  # @Reimport
+
+        # get the time bracket
+        try:
+            t_start, t_end = t_range  # type: ignore
+        except TypeError:
+            t_start, t_end = None, t_range
+        if t_start is None:
+            t_start = self.times[0]
+        if t_end is None:
+            t_end = self.times[-1]
+        
+        # determine the associated indices
+        i_start = np.searchsorted(self.times, t_start, side='left')
+        i_end = np.searchsorted(self.times, t_end, side='right')
+        
+        # extract the actual memory
+        return MemoryStorage(times=self.times[i_start:i_end],
+                             data=self.data[i_start:i_end],
+                             field_obj=self._field,
+                             info=self.info)
+        
+        
+            
 class StorageTracker(TrackerBase):
     """ Tracker that stores data in special storage classes 
     
