@@ -12,7 +12,6 @@ Miscallenous python functions
    skipUnlessModule
    get_progress_bar_class
    display_progress
-   add_scaled_colorbar
    import_class
    classproperty
    hybridmethod
@@ -272,41 +271,6 @@ def display_progress(iterator, total=None, enabled=True, **kwargs):
 
 
 
-def add_scaled_colorbar(im,
-                        ax=None,
-                        aspect: float = 20,
-                        pad_fraction: float = 0.5,
-                        **kwargs):
-    """ add a vertical color bar to an image plot
-    
-    The height of the colorbar is now adjusted to the plot, so that the width
-    determined by `aspect` is now given relative to the height. Moreover, the
-    gap between the colorbar and the plot is now given in units of the fraction
-    of the width by `pad_fraction`. 
-
-    Inspired by https://stackoverflow.com/a/33505522/932593
-    
-    Args:
-        im: object returned from :meth:`matplotlib.pyplot.imshow`
-        ax (:class:`matplotlib.axes.Axes`): the current figure axes
-        aspect (float): the target aspect ratio of the colorbar
-        pad_fraction (float): Width of the gap between colorbar and image
-        **kwargs: Additional parameters are passed to colorbar call
-
-    Returns:
-        the result of the colorbar call
-    """
-    from mpl_toolkits import axes_grid1
-    divider = axes_grid1.make_axes_locatable(im.axes)
-    width = axes_grid1.axes_size.AxesY(im.axes, aspect=1./aspect)
-    pad = axes_grid1.axes_size.Fraction(pad_fraction, width)
-    cax = divider.append_axes("right", size=width, pad=pad)
-#     if ax is not None:
-#         plt.sca(ax)
-    return im.axes.figure.colorbar(im, ax=ax, cax=cax, **kwargs)            
-       
-
-
 def import_class(identifier: str):
     """ import a class or module given an identifier 
     
